@@ -29,8 +29,9 @@ def qs_help():
     print(color_rep('    qs -rmbg <picture>       :-> remove image background'))
     print(color_rep('    qs -stbg pic to [from]   :-> color replace for picture'))
     print(color_rep('    qs -smms <picture/*.md>  :-> upload img to smms or all in .md'))
-    print(color_rep('    qs -ali_oss -help        :-> get aliyun nas api help menu'))
-    print(color_rep('    qs -qiniu -help          :-> get qiniu nas api help menu'))
+    print(color_rep('    qs -alioss -help        :-> get aliyun oss api help menu'))
+    print(color_rep('    qs -txcos -help          :-> get tencent cos api help menu'))
+    print(color_rep('    qs -qiniu -help          :-> get qiniu oss api help menu'))
     print(color_rep('    qs -weather [address]    :-> check weather (of address)'))
     print(color_rep('    qs -mktar <path...>      :-> create gzipped archive for path'))
     print(color_rep('    qs -untar <path>         :-> extract path.tar.*'))
